@@ -1,13 +1,12 @@
+import argparse
 import binascii
-from concurrent.futures import ThreadPoolExecutor
-from pathlib import Path
 import logging
+from concurrent.futures import ThreadPoolExecutor, wait
+from pathlib import Path
 
-from .assets import KNOWN_ASSETS, AssetStore, EXTRACTED_DIR, OVERRIDES_DIR
+from .assets import EXTRACTED_DIR, KNOWN_ASSETS, AssetStore
 
-DEFAULT_DIR = Path("Mods")
-EXTRACTED_DIR = DEFAULT_DIR / EXTRACTED_DIR
-OVERRIDES_DIR = DEFAULT_DIR / OVERRIDES_DIR
+DEFAULT_MODS_DIR = "Mods"
 
 DIRS = [
     "Data/Fonts",
@@ -17,24 +16,26 @@ DIRS = [
 
 
 def main():
-    import argparse
 
     parser = argparse.ArgumentParser(description="Extract Spelunky 2 Assets.")
     parser.add_argument("exe", type=argparse.FileType("rb"), help="Path to Spel2.exe")
+    parser.add_argument("--mods-dir", default=DEFAULT_MODS_DIR)
 
     args = parser.parse_args()
 
+    mods_dir = Path(args.mods_dir)
+
     logging.basicConfig(format="%(levelname)s - %(message)s", level=logging.INFO)
 
     asset_store = AssetStore.load_from_file(args.exe)
     seen = {}
 
     # Make all directories for extraction and overrides
+    (mods_dir / "Packs").mkdir(parents=True, exist_ok=True)
+    (mods_dir / "Overrides").mkdir(parents=True, exist_ok=True)
     for dir_ in DIRS:
-        (EXTRACTED_DIR / dir_).mkdir(parents=True, exist_ok=True)
-        (EXTRACTED_DIR / ".compressed" / dir_).mkdir(parents=True, exist_ok=True)
-        (OVERRIDES_DIR / dir_).mkdir(parents=True, exist_ok=True)
-        (OVERRIDES_DIR / ".compressed" / dir_).mkdir(parents=True, exist_ok=True)
+        (mods_dir / EXTRACTED_DIR / dir_).mkdir(parents=True, exist_ok=True)
+        (mods_dir / ".compressed" / EXTRACTED_DIR / dir_).mkdir(parents=True, exist_ok=True)
 
     for filename in KNOWN_ASSETS:
         asset = asset_store.find_asset(filename)
@@ -49,18 +50,21 @@ def main():
         asset.filename = filename
         seen[asset.name_hash] = asset
 
-        filepath = Path(filename.decode())
+        Path(filename.decode())
         asset.load_data(args.exe)
 
     def extract_single(asset):
         try:
             logging.info("Extracting %s... ", asset.filename.decode())
-            asset.extract(EXTRACTED_DIR, asset_store.key)
-        except Exception as err:
-            logging.error(err)
+            asset.extract(mods_dir, EXTRACTED_DIR, asset_store.key)
+        except Exception:
+            logging.exception("Failed Extraction")
 
     pool = ThreadPoolExecutor()
-    pool.map(extract_single, seen.values())
+    futures = [pool.submit(extract_single, asset) for asset in seen.values()]
+    wait(futures, timeout=300)
+    #for asset in seen.values():
+    #    extract_single(asset)
 
     for asset in sorted(asset_store.assets, key=lambda a: a.offset):
         name_hash = asset_store.filename_hash(asset.filename)
