@@ -1,18 +1,17 @@
-from PIL import Image
-from struct import pack
-import os
-from pathlib import Path
+import argparse
 import logging
+import os
+import shutil
+import sys
+from pathlib import Path
 
 from .assets import AssetStore, MissingAsset
 from .patcher import Patcher
 
+EXTRACTED_DIR = Path("Extracted")
+OVERRIDES_DIR = Path("Overrides")
 
 def main():
-    import argparse
-    import sys
-    import shutil
-
     parser = argparse.ArgumentParser(description="Extract Spelunky 2 Assets.")
 
     parser.add_argument(
@@ -21,6 +20,12 @@ def main():
         default="Mods",
         help="Path to directory containing mods.",
     )
+    parser.add_argument(
+        "--pack-dir",
+        action="append",
+        default=[],
+        help="Path to directory of mod pack to pack. Can be passed multiple times.",
+    )
     parser.add_argument(
         "--compression-level",
         type=int,
@@ -56,10 +61,15 @@ def main():
     print(f"Making copy of {args.source.name} to {args.dest}")
     shutil.copy2(args.source.name, args.dest)
 
+    search_dirs = []
+    for search_dir in args.pack_dir:
+        search_dirs.append(Path(search_dir).relative_to(args.mods_dir))
+    search_dirs.append(OVERRIDES_DIR)
+
     with open(args.dest, "rb+") as dest_file:
         asset_store = AssetStore.load_from_file(dest_file)
         try:
-            asset_store.repackage(Path(args.mods_dir), args.compression_level)
+            asset_store.repackage(Path(args.mods_dir), search_dirs, EXTRACTED_DIR, args.compression_level)
         except MissingAsset as err:
             print("")
             print(f"Failed to find expected asset: {err}. Unabled to proceed...")
